@@ -15,8 +15,8 @@
  *
  * You should have received a copy of the GNU Library General Public
  * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin St, Fifth Floor,
+ * Boston, MA 02110-1301, USA.
  */
 
 #ifndef TERMINAL_PROFILE_H
@@ -131,7 +131,7 @@ struct _TerminalProfileClass
 
 	void (* forgotten) (TerminalProfile           *profile);
 
-	GHashTable *mateconf_keys;
+	GHashTable *gsettings_keys;
 };
 
 GType             terminal_profile_get_type               (void);
