@@ -44,6 +44,13 @@
 #include "terminal-util.h"
 #include "terminal-window.h"
 
+#if GTK_CHECK_VERSION(3, 0, 0)
+ 	#define GDK_WINDOW_XWINDOW GDK_WINDOW_XID
+ 	#define GDK_DRAWABLE_XID GDK_WINDOW_XID
+#else
+	#define gdk_error_trap_pop_ignored gdk_error_trap_pop
+#endif
+
 void
 terminal_util_set_unique_role (GtkWindow *window, const char *prefix)
 {
@@ -145,44 +152,15 @@ terminal_util_show_help (const char *topic,
                          GtkWindow  *parent)
 {
 	GError *error = NULL;
-	const char *lang;
-	char *uri = NULL, *url;
-	guint i;
-
-	const char * const * langs = g_get_language_names ();
-	for (i = 0; langs[i]; i++)
-	{
-		lang = langs[i];
-		if (strchr (lang, '.'))
-		{
-			continue;
-		}
-
-		uri = g_build_filename (TERM_HELPDIR,
-		                        "mate-terminal", /* DOC_MODULE */
-		                        lang,
-		                        "mate-terminal.xml",
-		                        NULL);
-
-		if (g_file_test (uri, G_FILE_TEST_EXISTS))
-		{
-			break;
-		}
-
-		g_free (uri);
-		uri = NULL;
-	}
-
-	if (!uri)
-		return;
+	char *url;
 
 	if (topic)
 	{
-		url = g_strdup_printf ("ghelp://%s?%s", uri, topic);
+		url = g_strdup_printf ("help:mate-terminal/%s", topic);
 	}
 	else
 	{
-		url = g_strdup_printf ("ghelp://%s", uri);
+		url = g_strdup ("help:mate-terminal");
 	}
 
 	if (!open_url (GTK_WINDOW (parent), url, gtk_get_current_event_time (), &error))
@@ -192,7 +170,6 @@ terminal_util_show_help (const char *topic,
 		g_error_free (error);
 	}
 
-	g_free (uri);
 	g_free (url);
 }
 
@@ -634,7 +611,7 @@ setup_ignore_host_env (GHashTable *env_table,
 	GSList *ignore;
 	gchar **ignore_strv = g_settings_get_strv (settings, "ignore-hosts");
 
-	ignore = terminal_gsettings_strv_to_gslist (ignore_strv);
+	ignore = terminal_gsettings_strv_to_gslist ((const gchar *const *)ignore_strv);
 	if (ignore)
 	{
 		GString *buf = g_string_sized_new (64);
@@ -1049,7 +1026,11 @@ gboolean
 terminal_util_x11_get_net_wm_desktop (GdkWindow *window,
                                       guint32   *desktop)
 {
+	#if GTK_CHECK_VERSION(3, 0, 0)
+	GdkDisplay *display = gdk_window_get_display (window);
+	#else
 	GdkDisplay *display = gdk_drawable_get_display (window);
+	#endif
 	Atom type;
 	int format;
 	guchar *data;
@@ -1092,7 +1073,11 @@ terminal_util_x11_set_net_wm_desktop (GdkWindow *window,
 	 * http://bugzilla.mate.org/show_bug.cgi?id=586311 asks for GTK+
 	 * to just handle everything behind the scenes including the desktop.
 	 */
+	#if GTK_CHECK_VERSION(3, 0, 0)
+	GdkScreen *screen = gdk_window_get_screen (window);
+	#else
 	GdkScreen *screen = gdk_drawable_get_screen (window);
+	#endif
 	GdkDisplay *display = gdk_screen_get_display (screen);
 	Display *xdisplay = GDK_DISPLAY_XDISPLAY (display);
 	char *wm_selection_name;
@@ -1158,7 +1143,12 @@ terminal_util_x11_set_net_wm_desktop (GdkWindow *window,
 void
 terminal_util_x11_clear_demands_attention (GdkWindow *window)
 {
+
+	#if GTK_CHECK_VERSION(3, 0, 0)
+	GdkScreen *screen = gdk_window_get_screen (window);
+	#else
 	GdkScreen *screen = gdk_drawable_get_screen (window);
+	#endif
 	GdkDisplay *display = gdk_screen_get_display (screen);
 	XClientMessageEvent xclient;
 
@@ -1195,7 +1185,11 @@ terminal_util_x11_clear_demands_attention (GdkWindow *window)
 gboolean
 terminal_util_x11_window_is_minimized (GdkWindow *window)
 {
+	#if GTK_CHECK_VERSION(3, 0, 0)
+	GdkDisplay *display = gdk_window_get_display (window);
+	#else
 	GdkDisplay *display = gdk_drawable_get_display (window);
+	#endif
 
 	Atom type;
 	gint format;
@@ -1213,7 +1207,7 @@ terminal_util_x11_window_is_minimized (GdkWindow *window)
 	                    gdk_x11_get_xatom_by_name_for_display (display, "_NET_WM_STATE"),
 	                    0, G_MAXLONG, False, XA_ATOM, &type, &format, &nitems,
 	                    &bytes_after, &data);
-	gdk_error_trap_pop ();
+	gdk_error_trap_pop_ignored ();
 
 	if (type != None)
 	{
